VRMFirstPerson

Struct VRMFirstPerson 

pub struct VRMFirstPerson {
    pub first_person_bone: Option<Index<Node>>,
    pub first_person_bone_offset: Option<FirstPersonBoneOffset>,
    pub look_at_horizontal_inner: Option<VRMFirstPersonDegreeMap>,
    pub look_at_horizontal_outer: Option<VRMFirstPersonDegreeMap>,
    pub look_at_type_name: Option<LookAtTypeName>,
    pub look_at_vertical_down: Option<VRMFirstPersonDegreeMap>,
    pub look_at_vertical_up: Option<VRMFirstPersonDegreeMap>,
    pub mesh_annotations: Option<Vec<VRMFirstPersonMeshAnnotation>>,
}

Fields

first_person_bone: Option<Index<Node>>

The bone whose rendering should be turned off in first-person view. Usually Head is specified.

first_person_bone_offset: Option<FirstPersonBoneOffset>

The target position of the VR headset in first-person view. It is assumed that an offset from the head bone to the VR headset is added.

look_at_horizontal_inner: Option<VRMFirstPersonDegreeMap>look_at_horizontal_outer: Option<VRMFirstPersonDegreeMap>look_at_type_name: Option<LookAtTypeName>

Eye controller mode.

look_at_vertical_down: Option<VRMFirstPersonDegreeMap>look_at_vertical_up: Option<VRMFirstPersonDegreeMap>mesh_annotations: Option<Vec<VRMFirstPersonMeshAnnotation>>

Switch display / undisplay for each mesh in first-person view or the others.