VRMSecondaryAnimationSpring

Struct VRMSecondaryAnimationSpring 

pub struct VRMSecondaryAnimationSpring {
    pub bones: Option<Vec<Index<Node>>>,
    pub center: Option<Index<Node>>,
    pub collider_groups: Option<Vec<i64>>,
    pub comment: Option<String>,
    pub drag_force: Option<f64>,
    pub gravity_dir: Option<GravityDir>,
    pub gravity_power: Option<f64>,
    pub hit_radius: Option<f64>,
    pub stiffiness: Option<f64>,
}

Fields

bones: Option<Vec<Index<Node>>>

Specify the node index of the root bone of the swaying object.

center: Option<Index<Node>>

The reference point of a swaying object can be set at any location except the origin. When implementing UI moving with warp, the parent node to move with warp can be specified if you don’t want to make the object swaying with warp movement.

collider_groups: Option<Vec<i64>>

Specify the index of the collider group for collisions with swaying objects.

comment: Option<String>

Annotation comment

drag_force: Option<f64>

The resistance (deceleration) of automatic animation.

gravity_dir: Option<GravityDir>

The direction of gravity. Set (0, -1, 0) for simulating the gravity. Set (1, 0, 0) for simulating the wind.

gravity_power: Option<f64>

The strength of gravity.

hit_radius: Option<f64>

The radius of the sphere used for the collision detection with colliders.

stiffiness: Option<f64>

The resilience of the swaying object (the power of returning to the initial pose).