pub struct Spring {
pub center: Option<Index<Node>>,
pub collider_groups: Option<Vec<i64>>,
pub extensions: Option<FxHashMap<String, FxHashMap<String, Option<Value>>>>,
pub extras: Option<Value>,
pub joints: Vec<SpringBoneJoint>,
pub name: Option<String>,
}Expand description
A bone group of VRMCSpringBone.
Fields
center: Option<Index<Node>>An index of node which is used as a root of center space.
collider_groups: Option<Vec<i64>>Indices of ColliderGroups that detect collision with this spring.
extensions: Option<FxHashMap<String, FxHashMap<String, Option<Value>>>>extras: Option<Value>joints: Vec<SpringBoneJoint>Joints of the spring. Except for the first element, a previous joint of the array must be an ancestor of the joint.
name: Option<String>Name of the Spring